#!/usr/bin/env python
#
"""Generate random data for testing plotpick.py

For example::

  $ random-data.py | plotpick.py
"""

import random as _random

import numpy as _numpy


__version__ = '0.1'


class Linear (object):
    def __init__(self, a=1, b=1):
        self.a = a
        self.b = b

    def __call__(self, x):
        return self.a*x + self.b

def random_data(xmin=0, xmax=1, n=2**15, dx=0.1, dy=0.1, model=Linear()):
    for x in _numpy.linspace(xmin, xmax, n):
        y = model(x)
        rx = _random.gauss(mu=x, sigma=dx)
        ry = _random.gauss(mu=y, sigma=dy)
        yield (rx, ry)


if __name__ == '__main__':
    from argparse import ArgumentParser as _ArgumentParser

    parser = _ArgumentParser(
        description=__doc__, version=__version__)
    parser.add_argument(
        '-n', type=int, default=100,
        help='Number of random points to generate')

    args = parser.parse_args()

    for data in random_data(n=args.n):
        print('\t'.join(str(x) for x in data))
